"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "YappaActionButton", {
  enumerable: true,
  get: function () {
    return _YappaActionButton.default;
  }
});
exports.default = void 0;

var _reactNative = require("react-native");

var _YappaActionButton = _interopRequireDefault(require("./components/common/YappaActionButton"));

var _messaging = _interopRequireDefault(require("@react-native-firebase/messaging"));

var _pushNotificationIos = _interopRequireDefault(require("@react-native-community/push-notification-ios"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  Yappasdk
} = _reactNative.NativeModules;
const events = new _reactNative.NativeEventEmitter(_reactNative.NativeModules.Yappasdk);

const handleCachedNotification = callback => {
  // Case when a notification was generated in the foreground and then try to open it with the app closed.
  if (_reactNative.Platform.OS == "android") {
    Yappasdk.getNotificationData().then(data => {
      const {
        contentUrl,
        contentId
      } = data;
      console.log("contentUrl");
      console.log(contentUrl);
      callback(contentId || '', contentUrl || '', () => {
        console.log("callback");
        Yappasdk.initializeFromNotification();
      });
    });
  }
};

const handleNotification = (remoteMessage, callback) => {
  if (remoteMessage.data) {
    const contentId = remoteMessage.data.contentId;
    const contentUrl = remoteMessage.data.originalUrl;
    callback(contentId || '', contentUrl || '', () => {
      if (_reactNative.Platform.OS == 'ios') {
        Yappasdk.handleNotification(remoteMessage.data);
      } else {
        Yappasdk.handleNotification(remoteMessage);
      }
    });
  }
};

Yappasdk.handleRemoteNotification = callback => {
  handleCachedNotification(callback);

  if (_reactNative.Platform.OS == 'ios') {
    _pushNotificationIos.default.addEventListener('localNotification', notification => {
      const data = notification.getData();
      const {
        originalUrl,
        contentId
      } = data;
      callback(contentId || '', originalUrl || '', () => {
        Yappasdk.handleNotification(data);
      });
    });

    Yappasdk.setupObserver();
    events.addListener('YappaNotifHandler', value => {
      console.log("YappaNotifHandler");
      console.log(value);
      const {
        originalUrl,
        contentId
      } = value;
      callback(contentId || '', originalUrl || '', () => {
        Yappasdk.handleNotification(value);
      });
    });
  } else {
    events.addListener('YappaAndroidNotif', value => {
      console.log("YappaAndroidNotif");
      console.log(value);
      const {
        originalUrl,
        contentId
      } = value;
      callback(contentId || '', originalUrl || '', () => {
        Yappasdk.handleNotification(value);
      });
    });
  }

  (0, _messaging.default)().requestPermission().then(authStatus => {
    const enabled = authStatus === _messaging.default.AuthorizationStatus.AUTHORIZED || authStatus === _messaging.default.AuthorizationStatus.PROVISIONAL;
    console.log('-- enabled', enabled);

    if (enabled) {
      (0, _messaging.default)().getToken().then(fcmToken => {
        if (fcmToken) {
          console.log('Your Firebase Token is:', fcmToken);
          Yappasdk.setFCMToken(fcmToken);
        } else {
          console.log('Failed', 'No token received');
        }
      });
    }
  });
  (0, _messaging.default)().onMessage(async remoteMessage => {
    if (_reactNative.Platform.OS == 'ios') {
      if (remoteMessage != null && remoteMessage.notification != null) {
        const detail = {
          id: remoteMessage.messageId || "",
          title: remoteMessage.notification.title,
          subtitle: '',
          body: remoteMessage.notification.body,
          userInfo: remoteMessage.data
        };

        _pushNotificationIos.default.addNotificationRequest(detail);
      }
    } else {
      Yappasdk.handleNotificationForeground(remoteMessage);
      handleCachedNotification(callback);
    }
  });
  (0, _messaging.default)().getInitialNotification().then(remoteMessage => {
    if (_reactNative.Platform.OS == "android" && remoteMessage) {
      handleNotification(remoteMessage, callback);
    }
  });
  (0, _messaging.default)().onNotificationOpenedApp(remoteMessage => {
    handleNotification(remoteMessage, callback);
  });
};

var _default = Yappasdk;
exports.default = _default;
//# sourceMappingURL=index.js.map